@@ -649,6 +649,9 @@ def main():
 
         if args.optuna:
             from dvc_cc.run import optuna_scripts
+            rcc_branch_names = [exp_name+'_XXXXXXXXXX']
+            create_cc_config(dvc_files, exp_name, rcc_branch_names, args.num_of_repeats,
+                                args.live_output_files, args.live_output_update_frequence)
             optuna_scripts.create_optuna_directories(exp_name, vc)
             return
 
