@@ -159,6 +159,9 @@ def write_optuna_execution_script(path, inputs, input_branch_name, jobs, num_of_
         print('    from dvc_cc.hyperopt.variable import VariableCache', file=f)
         print('    import numpy as np', file=f)
         print('    import time', file=f)
+        print('    import os', file=f)
+        print('    from pathlib import Path', file=f)
+        print('', file=f)
         print('    vc = VariableCache()', file=f)
         print("    list_of_hyperopt_files = [f for f in os.listdir(str(Path('dvc/.hyperopt'))) if f.endswith('.hyperopt')]", file=f)
         print('    for f in list_of_hyperopt_files:', file=f)
@@ -186,7 +189,7 @@ def write_optuna_execution_script(path, inputs, input_branch_name, jobs, num_of_
         print('    vc.set_values_for_hyperopt_files(values, dvc_save_path=dvc_save_path)', file=f)
         print('', file=f)
         print('    # Create RED-YMLnano', file=f)
-        print("    with open('cc_execution_file_optuna.red.yml','r') as f:", file=f)
+        print("    with open('cc_execution_file.red.yml','r') as f:", file=f)
         print('        red_yml = f.read()', file=f)
         print("    red_yml = red_yml.replace('rcc_0032_MetricTest_XXXXXXXXXX', result_branch)", file=f)
         print("    with open(dvc_save_path+'/cc_execution_file.red.yml','w') as f:", file=f)
@@ -218,7 +221,7 @@ def write_optuna_execution_script(path, inputs, input_branch_name, jobs, num_of_
         print('                            load_if_exists=True', file=f)
         print('                           )', file=f)
         print('', file=f)
-        print('study.optimize(startbla, n_trials='+str(num_of_trials)+',n_jobs='+str(jobs)+')', file=f)
+        print('study.optimize(run_experiment, n_trials='+str(num_of_trials)+',n_jobs='+str(jobs)+')', file=f)
 
 
 # parameters
@@ -265,8 +268,7 @@ def write_metric_getter_script(path, input_branch_name, metric_path, save_summar
 
 def setting_batch_concurrency_limit():
     from pathlib import Path
-    from ruamel.yaml import YAML
-    yaml = YAML(typ='safe')
+    import yaml
 
     with open(str(Path(".dvc_cc/cc_config.yml")), 'r') as stream:
         settings = yaml.safe_load(stream)
